Page 33 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 33

Home

    propagate his philosophy.

    Masonic Lodges in France and Germany during the
    18th century became breeding grounds for revolution.
    Ideological evolution within the French lodges brought
    forth the Jacobin Clubs of revolutionary fame.

    It is important to distinguish between Freemasonry in
    Europe, especially France, from Freemasonry in England
    and America where, historically, and today, its members
    are usually characterized by high standards of morality
    and spirituality.

    To recruit members into the Order Weishaupt advised

    Seek out young and already skillful people. . . . Our
    people must be engaging, enterprising, intriguing, and
    adroit. Above all the first.’

    There is no way of influencing men so powerfully as
    by means of the women. These should therefore be our
    chief study; we should insinuate ourselves into their
    good opinion, give them hints of emancipation from
    tyranny of public opinion, and of standing up for
    themselves; it will be an immense relief to their enslaved
    minds to be freed from any one bond of restraint, and it
    will fire them the more, and cause them to work for us
    with zeal, without knowing that they do so; ...

    28

    The Secret Side of History

    Freemasons as a recruiting ground, and as a vehicle to

    his followers to:

    The Order did not overlook the usefulness of enlisting

    women in their cause, as evidenced by their written

    directives: